
#include "RunScorer.hh"
#include "DetectorConstruction.hh"
#include "G4RunManager.hh"
#include "G4Event.hh"
#include "G4SDManager.hh"
#include "G4HCofThisEvent.hh"
#include "G4THitsMap.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

RunScorer::RunScorer()
{
  G4SDManager* SDMan = G4SDManager::GetSDMpointer();
  eventColID = SDMan->GetCollectionID("myDetector/cellFlux");
  G4cout << "\n  Collection ID = " << eventColID << G4endl;
  
  DetectorConstruction* detector = (DetectorConstruction*)
  (G4RunManager::GetRunManager()->GetUserDetectorConstruction());
  drRing = detector->GetDrRing();
  G4cout << "\n  drRing = " << drRing << " mm" << G4endl;  
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

RunScorer::~RunScorer()
{ }

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void RunScorer::RecordEvent(const G4Event* evt)
{
  //count number of events (mandatory !)
  //
  numberOfEvent++;
  
  //Hits collections
  //    
  G4HCofThisEvent* HCE = evt->GetHCofThisEvent();
  if(!HCE) return;

  G4THitsMap<G4double>* evtMap = 
                     (G4THitsMap<G4double>*)(HCE->GetHC(eventColID));

  std::map<G4int,G4double*>::iterator itr = evtMap->GetMap()->begin();
  for (; itr != evtMap->GetMap()->end(); itr++) {
    G4int copyNb = (itr->first);
    G4double val = *(itr->second);
    G4double ringArea = twopi*(copyNb + 0.5)*drRing*drRing;
    G4cout << "\n Ring copy nb: " << copyNb 
           << "\t1/dS: " << 1./ringArea << "/mm2"
	   << "\tcell Flux: " << val << "/mm2" << G4endl;
  }
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
